RolleeConnectConfig class
This class represents the Rollee Connect configuration.
- Annotations
Constructors
- RolleeConnectConfig({required String sessionToken, required String token, RolleeConnectConfigSetup? setup})
-
This class represents the Rollee Connect configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionToken → String
-
The user session token on Rollee Connect application.
final
- setup → RolleeConnectConfigSetup?
-
The Rollee Connect configuration setup.
final
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - token → String
-
The Rollee Connect token.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited