RolleeConnectParams class
This class represents the Rollee Connect parameters.
- Annotations
Constructors
Properties
- ctaButtonBackColor → String?
-
the background color of the CTA button.
final
- ctaButtonForeColor → String?
-
the text color of the CTA button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- introScreenTitle → String?
-
the title of the intro screen.
final
- partnerLogo → String?
-
the partner logo url.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- redirect → String?
-
the redirect url.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Creates a Map from the RolleeConnectParams object. This is used to pass the parameters to the native side.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited